@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dired-video-thumbnail" "0.1.0"
+(define-package "dired-video-thumbnail" "20251215.816"
   "Display video thumbnails from dired."
   '((emacs "28.1"))
   :url "https://github.com/captainflasmr/dired-video-thumbnail"
-  :commit "316c668e93e07176201f493d85dcdb7fcf8d682e"
-  :revdesc "316c668e93e0"
+  :commit "4735c6d81c48228f9dccc48a09ca715bf2e6ffad"
+  :revdesc "4735c6d81c48"
   :keywords '("multimedia" "files" "dired"))
